@@ -4,9 +4,10 @@ fn main() {
   App::new()
     .add_plugins(DefaultPlugins)
     .add_plugin(FighterInputPlugin)
+    // .add_plugin(LogDiagnosticsPlugin::default())
+    // .add_plugin(FrameTimeDiagnosticsPlugin::default())
     .insert_resource(CollisionBoxColors::new(0.4))
     .add_startup_system(setup)
-    //.add_system(read_gamepad_inputs)
     .add_system_set(
       SystemSet::new()
         .with_run_criteria(FixedTimestep::step(0.01667))
@@ -36,11 +37,11 @@ fn add_hitbox(
   keyboard_input: Res<Input<KeyCode>>,
   button_input: Res<Input<GamepadButton>>,
   player_inputs: Res<PlayerInputs>,
-  query: Query<(&PlayerId, &PlayerMovement, Entity)>,
+  query: Query<(&PlayerMovement, Entity)>,
 ) -> () {
-  for (player_id, player_movement, entity) in query.iter() {
+  for (player_movement, entity) in query.iter() {
     for mapper in player_inputs.local_devices.iter() {
-      if mapper.player_id == player_id.0 {
+      if mapper.player_id == player_movement.player_id {
         let InputActionsPressed {a, ..} = mapper.get_just_pressed_buttons(&keyboard_input, &button_input);
 
         if a {
@@ -48,11 +49,11 @@ fn add_hitbox(
             &mut commands,
             box_colors.hitbox_color,
             entity,
-            player_id.0,
+            player_movement.player_id,
             Vec2::new(40.0,20.0),
             Vec2::new(15.0*player_movement.get_facing_vector(), 25.0),
             Hitbox::new(
-              player_id.0,
+              player_movement.player_id,
               false,
               HitboxData::jab(5) ,
               AttackProperty::MID,
@@ -65,61 +66,62 @@ fn add_hitbox(
   }
 }
 
-
-fn read_gamepad_inputs(mut gamepad_event: EventReader<GamepadEvent>) {
-    for event in gamepad_event.iter() {
-        match &event {
-            GamepadEvent(gamepad, GamepadEventType::Connected) => {
-                info!("{:?} Connected", gamepad);
-            }
-            GamepadEvent(gamepad, GamepadEventType::Disconnected) => {
-                info!("{:?} Disconnected", gamepad);
-            }
-            GamepadEvent(gamepad, GamepadEventType::ButtonChanged(button_type, value)) => {
-                info!("Button {:?} of {:?} is changed to {}", button_type, gamepad, value);
-            }
-            GamepadEvent(gamepad, GamepadEventType::AxisChanged(axis_type, value)) => {
-                info!("Axis {:?} of {:?} is changed to {}", axis_type, gamepad, value);
-            }
-        }
-    }
-}
 fn setup(
     mut coms: Commands,
-    box_colors: Res<CollisionBoxColors>,
+    //box_colors: Res<CollisionBoxColors>,
 ) {
     load_character_sprite_data("./src/test.json");
     coms.spawn_bundle(OrthographicCameraBundle::new_2d());
     coms.spawn_bundle(UiCameraBundle::default());
 
-    let player = coms
+    coms
       .spawn_bundle(SpriteBundle {
         sprite: Sprite{
-          color: Color::RED,
+          color: Color::TEAL,
           custom_size: Some(Vec2::new(30.0, 60.0)),
           ..Default::default()
         },
-        transform: Transform::default(),
+        transform: Transform::from_xyz(-40.0, 0.0, 0.0),
         ..Default::default()
       })
-      .insert(PlayerMovement::new())
-      .id();
+      .insert(PlayerMovement {
+        player_id: 1,
+        facing_right: true,
+        ..Default::default()
+      });
 
-    let hurtbox = coms
+    coms
       .spawn_bundle(SpriteBundle {
         sprite: Sprite{
-          color: box_colors.hurtbox_color,
-          custom_size: Some(Vec2::new(35.0, 35.0)),
+          color: Color::INDIGO,
+          custom_size: Some(Vec2::new(30.0, 60.0)),
           ..Default::default()
         },
-        transform: Transform::from_xyz(0.0, -12.5, 1.0),
+        transform: Transform::from_xyz(40.0, 0.0, 0.0),
         ..Default::default()
       })
-      .insert(Hurtbox {
-        player_id: 1,
+      .insert(PlayerMovement {
+        player_id: 2,
+        facing_right: false,
         ..Default::default()
-      })
-      .id();
+      });
+      //.id();
+
+    // let hurtbox = coms
+    //   .spawn_bundle(SpriteBundle {
+    //     sprite: Sprite{
+    //       color: box_colors.hurtbox_color,
+    //       custom_size: Some(Vec2::new(35.0, 35.0)),
+    //       ..Default::default()
+    //     },
+    //     transform: Transform::from_xyz(0.0, -12.5, 1.0),
+    //     ..Default::default()
+    //   })
+    //   .insert(Hurtbox {
+    //     player_id: 1,
+    //     ..Default::default()
+    //   })
+    //   .id();
     
-    coms.entity(player).push_children(&[hurtbox]);
+    // coms.entity(player).push_children(&[hurtbox]);
 }
