@@ -27,18 +27,18 @@ impl Default for PlayerInputs {
         },
           InputMapper {
             player_id: 2,
-            a: RawButton::K(KeyCode::J),
-            b: RawButton::K(KeyCode::K),
-            c: RawButton::K(KeyCode::L),
-            d: RawButton::K(KeyCode::N),
-            e: RawButton::K(KeyCode::J),
-            f: RawButton::K(KeyCode::K),
-            macro_1: RawButton::K(KeyCode::L),
-            macro_2: RawButton::K(KeyCode::N),
-            x_positive: RawButton::K(KeyCode::D),
-            x_negative: RawButton::K(KeyCode::A),
-            y_positive: RawButton::K(KeyCode::V),
-            y_negative: RawButton::K(KeyCode::S),
+            a: RawButton::K(KeyCode::Y),
+            b: RawButton::K(KeyCode::U),
+            c: RawButton::K(KeyCode::I),
+            d: RawButton::K(KeyCode::G),
+            e: RawButton::K(KeyCode::H),
+            f: RawButton::K(KeyCode::J),
+            macro_1: RawButton::K(KeyCode::O),
+            macro_2: RawButton::K(KeyCode::K),
+            x_positive: RawButton::K(KeyCode::E),
+            x_negative: RawButton::K(KeyCode::Q),
+            y_positive: RawButton::K(KeyCode::Space),
+            y_negative: RawButton::K(KeyCode::W),
             facing_right: false,
         },
       ],
@@ -87,12 +87,12 @@ impl InputMapper {
         RawButton::G(device_id,button_type) => button_input.pressed(GamepadButton(device_id, button_type)),
       };
 
-      let down_pressed = match self.y_positive {
+      let down_pressed = match self.y_negative {
         RawButton::K(keycode) => keyboard_input.pressed(keycode),
         RawButton::G(device_id,button_type) => button_input.pressed(GamepadButton(device_id, button_type)),
       };
 
-      let up_pressed = match self.y_negative {
+      let up_pressed = match self.y_positive {
         RawButton::K(keycode) => keyboard_input.pressed(keycode),
         RawButton::G(device_id,button_type) => button_input.pressed(GamepadButton(device_id, button_type)),
       };
